<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="71"/>
        <source>Deepin Home</source>
        <translation>Deepin Anasayfa</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Ana pencereyi göster</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="89"/>
        <source>Communication</source>
        <translation>İletişim</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="92"/>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="333"/>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
</context>
</TS>